@@ -37,7 +37,9 @@ __all__ = (
     "DescribeOrderableDBInstanceOptionsPaginatorName",
     "DescribePendingMaintenanceActionsPaginatorName",
     "SourceTypeType",
+    "DocDBServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -67,6 +69,7 @@ SourceTypeType = Literal[
     "db-security-group",
     "db-snapshot",
 ]
+DocDBServiceName = Literal["docdb"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -98,6 +101,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -220,6 +224,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -368,6 +373,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_certificates",
     "describe_db_cluster_parameter_groups",
